<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Névjegy...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Infó</translation>
    </message>
    <message>
        <location filename="../about.ui" line="53"/>
        <location filename="../about.ui" line="109"/>
        <location filename="../about.ui" line="165"/>
        <source>icon</source>
        <translation>ikon</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Fordítók</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Licensz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>SMPlayer YouTube%1 Böngészője</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>Based on UMPlayer</source>
        <translation>UMPlayer alapján</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Verzió: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Hordozható Kiadás</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Fordítva Qt %1-l (használt Qt: %2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our web for updates:</source>
        <translation>Frissítésekért látogassa meg a weboldalunkat:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="98"/>
        <source>Spanish</source>
        <translation>Spanyol</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="115"/>
        <source>Russian</source>
        <translation>Orosz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="108"/>
        <source>Lithuanian</source>
        <translation>Litván</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="102"/>
        <source>Japanese</source>
        <translation>Japán</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="99"/>
        <source>Basque</source>
        <translation>Baszk</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="104"/>
        <source>Portuguese</source>
        <translation>Portugál (Brazil)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="119"/>
        <source>Hungarian</source>
        <translation>Magyar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="114"/>
        <source>Polish</source>
        <translation>Lengyel</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="111"/>
        <source>Hebrew</source>
        <translation>Héber</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="106"/>
        <source>Ukrainian</source>
        <translation>Ukrán</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="125"/>
        <source>Norwegian Nynorsk</source>
        <translation>Norvég</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="101"/>
        <source>Czech</source>
        <translation>Cseh</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="92"/>
        <source>Many people contributed with translations.</source>
        <translation>Sokan hozzájárultak a fordításhoz.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="93"/>
        <source>You can also help to translate SMPlayer into your own language.</source>
        <translation>Te is tudsz segíteni az SMPlayer lefordításában.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>Látogasd meg a %1 címet és csatlakozz valamelyik fordítói csapathoz.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="96"/>
        <source>Current translators from the transifex teams:</source>
        <translation>A Transifex csapatok jelenlegi fordítói:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="103"/>
        <source>Korean</source>
        <translation>Koreai</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="109"/>
        <source>Malay</source>
        <translation>Maláj</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="110"/>
        <source>Portuguese - Brazil</source>
        <translation>Portugál - Brazil</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="112"/>
        <source>Simplified Chinese</source>
        <translation>Egyszerűsített kínai</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="116"/>
        <source>French</source>
        <translation>Francia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="118"/>
        <source>Danish</source>
        <translation>Dán</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="122"/>
        <source>German</source>
        <translation>Német</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="123"/>
        <source>Traditional Chinese</source>
        <translation>Hagyományos kínai</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="126"/>
        <source>Swedish</source>
        <translation>Svéd</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="120"/>
        <source>Turkish</source>
        <translation>Török</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="121"/>
        <source>Finnish</source>
        <translation>Finn</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="127"/>
        <source>Arabic</source>
        <translation>Arab</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="128"/>
        <source>Georgian</source>
        <translation>Grúz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="105"/>
        <source>Serbian</source>
        <translation>Szerb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="100"/>
        <source>Croatian</source>
        <translation>Horvát</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="124"/>
        <source>Bulgarian</source>
        <translation>Bolgár</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="113"/>
        <source>Vietnamese</source>
        <translation>Vietnami</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>Indonesian</source>
        <translation>Indonéz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="129"/>
        <source>Arabic - Saudi Arabia</source>
        <translation>Arab - Szaúd-Arábia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="130"/>
        <source>Sinhala</source>
        <translation>Szimhala</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="131"/>
        <source>Greek</source>
        <translation>Görög</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="132"/>
        <source>Estonian</source>
        <translation>Észt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="133"/>
        <source>N&apos;ko</source>
        <translation>N&apos;ko</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="134"/>
        <source>Italian</source>
        <translation>Olasz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="135"/>
        <source>Uzbek</source>
        <translation>Üzbég</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="136"/>
        <source>Catalan</source>
        <translation>Katalán</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="137"/>
        <source>Slovak</source>
        <translation>Szlovák</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="138"/>
        <source>British English</source>
        <translation>Brit Angol</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="139"/>
        <source>Albanian</source>
        <translation>Albánia</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="140"/>
        <source>Dutch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="141"/>
        <source>Romanian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="142"/>
        <source>Khmer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="143"/>
        <source>Telugu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="144"/>
        <source>Tamil</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="145"/>
        <source>Malayalam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="170"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="107"/>
        <source>Galician</source>
        <translation>Galíciai</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="37"/>
        <source>Downloading...</source>
        <translation>Letöltés...</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="58"/>
        <source>Connecting to %1</source>
        <translation>Kapcsolódás %1-hoz...</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="126"/>
        <source>The Youtube code has been updated successfully.</source>
        <translation>A Youtube kód sikeresen frissítve.</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="127"/>
        <source>Installed version: %1</source>
        <translation>Telepített verzió: %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="128"/>
        <source>Success</source>
        <translation>Sikerült</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="133"/>
        <location filename="../codedownloader.cpp" line="138"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="133"/>
        <source>An error happened writing %1</source>
        <translation>Hiba történt írás közben: %1</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="138"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation>Hiba történt a fájl letöltése közben:&lt;br&gt;%1</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="20"/>
        <source>Recording</source>
        <translation>Felvétel</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="28"/>
        <source>&amp;Save to this folder</source>
        <translation>&amp;Mentés ebbe a mappába</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="45"/>
        <source>&amp;Quality</source>
        <translation>&amp;Minőség</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="157"/>
        <source>Standard Feeds</source>
        <translation>Szűrők</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="163"/>
        <source>&amp;Region:</source>
        <translation>&amp;Terület:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="189"/>
        <source>Period of &amp;time:</source>
        <translation>I&amp;dőszak:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="80"/>
        <source>Playback</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="88"/>
        <source>Q&amp;uality:</source>
        <translation>M&amp;inőség:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="125"/>
        <source>&amp;Player:</source>
        <translation>&amp;Lejátszó:</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="40"/>
        <source>All time</source>
        <translation>Mindenkor</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="41"/>
        <source>This month</source>
        <translation>Ebben a hónapban</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="42"/>
        <source>This week</source>
        <translation>Ezen a héten</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="43"/>
        <source>Today</source>
        <translation>Ma</translation>
    </message>
</context>
<context>
    <name>DownloadFile</name>
    <message>
        <location filename="../downloadfile.cpp" line="117"/>
        <source>%1 hours</source>
        <translation>%1 óra</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="123"/>
        <source>%1 minutes</source>
        <translation>%1 perc</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="110"/>
        <source>unknown time remaining</source>
        <translation>a hátralévő idő ismeretlen</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="126"/>
        <source>%1 seconds</source>
        <translation>%1 másodperc</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="127"/>
        <source>%1 remaining</source>
        <translation>hátralévő idő: %1</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="132"/>
        <source>%1 of %2 MB</source>
        <translation>%2 MB-ból %1</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="138"/>
        <source>%1 of %2 KB</source>
        <translation>%2 KB-ból %1</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="144"/>
        <source>%1 of %2 bytes</source>
        <translation>%2 byte-ből %1</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="148"/>
        <source>%1 of unknown size</source>
        <translation>%1 mérete ismeretlen</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="153"/>
        <source>%1 MB/sec</source>
        <translation>%1 MB/mp</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="157"/>
        <source>%1 KB/sec</source>
        <translation>%1 KB/mp</translation>
    </message>
    <message>
        <location filename="../downloadfile.cpp" line="161"/>
        <source>%1 bytes/sec</source>
        <translation>%1 bytes/mp</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="54"/>
        <source>Click to select a file or folder</source>
        <translation>Válasszon egy fájlt vagy egy mappát</translation>
    </message>
</context>
<context>
    <name>RecordingDelegate</name>
    <message>
        <location filename="../recordingdialog.cpp" line="125"/>
        <source>Canceled</source>
        <translation>Megszakítva</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="125"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="155"/>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="159"/>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="163"/>
        <source>%1 bytes</source>
        <translation>%1 bytes</translation>
    </message>
</context>
<context>
    <name>RecordingDialog</name>
    <message>
        <location filename="../recordingdialog.cpp" line="208"/>
        <location filename="../recordingdialog.cpp" line="527"/>
        <source>Recordings</source>
        <translation>Felvételek</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="209"/>
        <source>&amp;Clear list</source>
        <translation>&amp;Lista törlése</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="210"/>
        <location filename="../recordingdialog.cpp" line="658"/>
        <source>&amp;Open folder</source>
        <translation>&amp;Mappa megnyitása</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="345"/>
        <location filename="../recordingdialog.cpp" line="357"/>
        <location filename="../recordingdialog.cpp" line="777"/>
        <source>There was an error in retrieving the download URL.</source>
        <translation>Hiba történt a letöltendő URL visszakeresésében.</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="345"/>
        <location filename="../recordingdialog.cpp" line="357"/>
        <location filename="../recordingdialog.cpp" line="777"/>
        <source>Recording failed</source>
        <translation>Sikertelen felvétel</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="413"/>
        <location filename="../recordingdialog.cpp" line="795"/>
        <source>Starting</source>
        <translation>Indítás</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="448"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="452"/>
        <source>Completed</source>
        <translation>Befejezve</translation>
    </message>
    <message numerus="yes">
        <location filename="../recordingdialog.cpp" line="531"/>
        <source>%1% of %n video - Recordings</source>
        <translation>
            <numerusform>%n videó %1%-a - Felvételek</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="616"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Mégse</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="618"/>
        <source>&amp;Remove from list</source>
        <translation>&amp;Eltávolítás a listáról</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="639"/>
        <location filename="../recordingdialog.cpp" line="661"/>
        <source>Remove from &amp;list</source>
        <translation>Eltávolítás a &amp;listáról</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="635"/>
        <source>&amp;Retry</source>
        <translation>&amp;Újból</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="657"/>
        <source>&amp;Play</source>
        <translation>&amp;Lejátszás</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="660"/>
        <source>&amp;Delete</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="742"/>
        <source>Fetching URL...</source>
        <translation>URL betöltése...</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="759"/>
        <source>File error</source>
        <translation>Fájl hiba</translation>
    </message>
    <message>
        <location filename="../recordingdialog.cpp" line="760"/>
        <source>The file does not exists, would you like to remove it from the list?</source>
        <translation>A fájl nem létezik, eltávolítja a listáról?</translation>
    </message>
</context>
<context>
    <name>Regions</name>
    <message>
        <location filename="../regions.cpp" line="26"/>
        <source>Argentina</source>
        <translation>Argentína</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="27"/>
        <source>Australia</source>
        <translation>Ausztrália</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="29"/>
        <source>Belgium</source>
        <translation>Belgium</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="30"/>
        <source>Brazil</source>
        <translation>Brazília</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="31"/>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="32"/>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="33"/>
        <source>Colombia</source>
        <translation>Kolumbia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="34"/>
        <source>Czech Republic</source>
        <translation>Csehország</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="35"/>
        <source>Egypt</source>
        <translation>Egyiptom</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="36"/>
        <source>France</source>
        <translation>Franciaország</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="37"/>
        <source>Germany</source>
        <translation>Németország</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="38"/>
        <source>Great Britain</source>
        <translation>Nagy-Britannia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="39"/>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="40"/>
        <source>Hungary</source>
        <translation>Magyarország</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="41"/>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="42"/>
        <source>Ireland</source>
        <translation>Írország</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="43"/>
        <source>Israel</source>
        <translation>Izrael</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="44"/>
        <source>Italy</source>
        <translation>Olaszország</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="45"/>
        <source>Japan</source>
        <translation>Japán</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="46"/>
        <source>Jordan</source>
        <translation>Jordánia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="47"/>
        <source>Malaysia</source>
        <translation>Malajzia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="48"/>
        <source>Mexico</source>
        <translation>Mexikó</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="49"/>
        <source>Morocco</source>
        <translation>Marokkó</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="50"/>
        <source>Netherlands</source>
        <translation>Hollandia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="51"/>
        <source>New Zealand</source>
        <translation>Új-Zéland</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="52"/>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="53"/>
        <source>Philippines</source>
        <translation>Fülöp-szigetek</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="54"/>
        <source>Poland</source>
        <translation>Lengyelország</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="55"/>
        <source>Russia</source>
        <translation>Oroszország</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="56"/>
        <source>Saudi Arabia</source>
        <translation>Szaúd-Arábia</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="57"/>
        <source>Singapore</source>
        <translation>Szingapúr</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="58"/>
        <source>South Africa</source>
        <translation>Dél-Afrika</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="59"/>
        <source>South Korea</source>
        <translation>Dél-Korea</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="60"/>
        <source>Spain</source>
        <translation>Spanyolország</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="61"/>
        <source>Sweden</source>
        <translation>Svédország</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="63"/>
        <source>Taiwan</source>
        <translation>Tajvan</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="64"/>
        <source>United Arab Emirates</source>
        <translation>Egyesült Arab Emírségek</translation>
    </message>
    <message>
        <location filename="../regions.cpp" line="65"/>
        <source>United States</source>
        <translation>Egyesült Államok</translation>
    </message>
</context>
<context>
    <name>YTDelegate</name>
    <message>
        <location filename="../ytdelegate.cpp" line="115"/>
        <source>%L1 views</source>
        <translation>%L1 megtekintés</translation>
    </message>
</context>
<context>
    <name>YTDialog</name>
    <message>
        <location filename="../ytdialog.cpp" line="227"/>
        <source>YouTube Browser - SMPlayer</source>
        <translation>YouTube Böngésző - SMPlayer</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="277"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="283"/>
        <source>Information</source>
        <translation>Információ</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="290"/>
        <source>Show recordings</source>
        <translation>Felvételek lista</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="296"/>
        <source>Enter URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="497"/>
        <source>Most Relevant</source>
        <translation>Kapcsolódó videók</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="501"/>
        <source>Most Recent</source>
        <translation>Legfrissebb</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="505"/>
        <source>Most Viewed</source>
        <translation>Legnézettebb</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="509"/>
        <source>Most Popular</source>
        <translation>Népszerű</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="535"/>
        <source>Most popular videos on YouTube%1</source>
        <translation>Népszerű videók a YouTube-on%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="656"/>
        <source>Error: Could not connect to Youtube server.</source>
        <translation>Hiba: Nem sikerült csatlakozni a Youtube szerveréhez.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="766"/>
        <source>R&amp;ecord audio</source>
        <translation>&amp;Hang rögzítése</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="771"/>
        <source>&amp;Add URL to the SMPlayer playlist</source>
        <translation>URL &amp;hozzáadása az SMPlayer lejátszási listájához</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="839"/>
        <source>Enter a URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="963"/>
        <location filename="../ytdialog.cpp" line="974"/>
        <source>Problems with Youtube</source>
        <translation>Problémák a Youtube-bal</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="965"/>
        <source>Do you want to update the Youtube code? This may fix the problem.</source>
        <translation>Szeretné frissíteni a Youtube kódot? Ez megoldja a problémát.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="964"/>
        <location filename="../ytdialog.cpp" line="975"/>
        <source>Unfortunately due to changes in Youtube, the video &apos;%1&apos; can&apos;t be played or recorded.</source>
        <translation>Sajnos a Youtube-on történt változások miatt, a(z) &apos;%1&apos; videót nem lehet lejátszani vagy rögzíteni.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="976"/>
        <source>Maybe updating this application could fix the problem.</source>
        <translation>Lehet, hogy az alkalmazás frissítése megoldja a problémát.</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="540"/>
        <source>YouTube%2 results for &quot;%1&quot;</source>
        <translation>YouTube%2 videótalálatok: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="513"/>
        <source>Music</source>
        <translation>Zene</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="517"/>
        <source>Sports</source>
        <translation>Sportok</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="536"/>
        <source>Most popular sport videos on YouTube%1</source>
        <translation>Legnépszerűbb sport videók a Youtube-on%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="537"/>
        <source>Most popular music videos on YouTube%1</source>
        <translation>Legnépszerűbb zenei videók a Youtube-on%1</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="664"/>
        <source>No videos found</source>
        <translation>Nincs videótalálat</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="666"/>
        <source>No videos found for &quot;%1&quot;</source>
        <translation>Nincs videotalálat a következő keresésre: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="763"/>
        <source>&amp;Play video</source>
        <translation>&amp;Videó lejátszása</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="765"/>
        <source>&amp;Record video</source>
        <translation>&amp;Videó rögzítése</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="768"/>
        <source>&amp;Watch on YouTube</source>
        <translation>&amp;Megtekintés a YouTube-on</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="769"/>
        <source>&amp;Copy link</source>
        <translation>&amp;Hivatkozás másolása</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="252"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="258"/>
        <source>Previous</source>
        <translation>Előző</translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="840"/>
        <source>Enter a Youtube URL to record</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ytdialog.cpp" line="949"/>
        <location filename="../ytdialog.cpp" line="951"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
</context>
</TS>
